/*
 *  A function illustrating how to link C code to code generated from LLVM 
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
/*
 * Font information: one byte per row, 8 rows per character
 * In order, space, 0-9, A-Z
 */
static const char font[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x1c, 0x3e, 0x61, 0x41, 0x43, 0x3e, 0x1c, 0x00,
  0x00, 0x40, 0x42, 0x7f, 0x7f, 0x40, 0x40, 0x00,
  0x62, 0x73, 0x79, 0x59, 0x5d, 0x4f, 0x46, 0x00,
  0x20, 0x61, 0x49, 0x4d, 0x4f, 0x7b, 0x31, 0x00,
  0x18, 0x1c, 0x16, 0x13, 0x7f, 0x7f, 0x10, 0x00,
  0x27, 0x67, 0x45, 0x45, 0x45, 0x7d, 0x38, 0x00,
  0x3c, 0x7e, 0x4b, 0x49, 0x49, 0x79, 0x30, 0x00,
  0x03, 0x03, 0x71, 0x79, 0x0d, 0x07, 0x03, 0x00,
  0x36, 0x4f, 0x4d, 0x59, 0x59, 0x76, 0x30, 0x00,
  0x06, 0x4f, 0x49, 0x49, 0x69, 0x3f, 0x1e, 0x00,
  0x7c, 0x7e, 0x13, 0x11, 0x13, 0x7e, 0x7c, 0x00,
  0x7f, 0x7f, 0x49, 0x49, 0x49, 0x7f, 0x36, 0x00,
  0x1c, 0x3e, 0x63, 0x41, 0x41, 0x63, 0x22, 0x00,
  0x7f, 0x7f, 0x41, 0x41, 0x63, 0x3e, 0x1c, 0x00,
  0x00, 0x7f, 0x7f, 0x49, 0x49, 0x49, 0x41, 0x00,
  0x7f, 0x7f, 0x09, 0x09, 0x09, 0x09, 0x01, 0x00,
  0x1c, 0x3e, 0x63, 0x41, 0x49, 0x79, 0x79, 0x00,
  0x7f, 0x7f, 0x08, 0x08, 0x08, 0x7f, 0x7f, 0x00,
  0x00, 0x41, 0x41, 0x7f, 0x7f, 0x41, 0x41, 0x00,
  0x20, 0x60, 0x40, 0x40, 0x40, 0x7f, 0x3f, 0x00,
  0x7f, 0x7f, 0x18, 0x3c, 0x76, 0x63, 0x41, 0x00,
  0x00, 0x7f, 0x7f, 0x40, 0x40, 0x40, 0x40, 0x00,
  0x7f, 0x7f, 0x0e, 0x1c, 0x0e, 0x7f, 0x7f, 0x00,
  0x7f, 0x7f, 0x0e, 0x1c, 0x38, 0x7f, 0x7f, 0x00,
  0x3e, 0x7f, 0x41, 0x41, 0x41, 0x7f, 0x3e, 0x00,
  0x7f, 0x7f, 0x11, 0x11, 0x11, 0x1f, 0x0e, 0x00,
  0x3e, 0x7f, 0x41, 0x51, 0x71, 0x3f, 0x5e, 0x00,
  0x7f, 0x7f, 0x11, 0x31, 0x79, 0x6f, 0x4e, 0x00,
  0x26, 0x6f, 0x49, 0x49, 0x4b, 0x7a, 0x30, 0x00,
  0x00, 0x01, 0x01, 0x7f, 0x7f, 0x01, 0x01, 0x00,
  0x3f, 0x7f, 0x40, 0x40, 0x40, 0x7f, 0x3f, 0x00,
  0x0f, 0x1f, 0x38, 0x70, 0x38, 0x1f, 0x0f, 0x00,
  0x1f, 0x7f, 0x38, 0x1c, 0x38, 0x7f, 0x1f, 0x00,
  0x63, 0x77, 0x3e, 0x1c, 0x3e, 0x77, 0x63, 0x00,
  0x00, 0x03, 0x0f, 0x78, 0x78, 0x0f, 0x03, 0x00,
  0x61, 0x71, 0x79, 0x5d, 0x4f, 0x47, 0x43, 0x00
};

void printbig(int c)
{
  int index = 0;
  int col, data;
  if (c >= '0' && c <= '9') index = 8 + (c - '0') * 8;
  else if (c >= 'A' && c <= 'Z') index = 88 + (c - 'A') * 8;
  do {
    data = font[index++];
    for (col = 0 ; col < 8 ; data <<= 1, col++) {
      char d = data & 0x80 ? 'X' : ' ';
      putchar(d); putchar(d);
    }
    putchar('\n');
  } while (index & 0x7); 
}

char* read_csv(char* filename){
  FILE* file = fopen(filename, "r");
  int file_length;
  int res;
  char* buffer;
  if (file == NULL){
    exit(1);
  }
  fseek(file, 0, SEEK_END);
  file_length = ftell(file);
  rewind(file);
  buffer = (char*)malloc(file_length);
  res = fread(buffer, 1, file_length,file);
  if (res == 0){
    fclose(file);
    perror("This file could not be read. Check if file exists or correct path is given.");
  }
  else{
    fclose(file);
    return buffer;
  }
}


void parse(char* text, char* delimeter){
  char* res;
  res = strtok(text, delimeter);
  while (res != NULL){
    printf("%s\n", res);
    res = strtok(NULL, delimeter);
  }
}


char* sim(char* filename1, char* filename2){
  //Open all files for reading
  FILE* file1 = fopen(filename1, "r");
  FILE* file2 = fopen(filename2, "r");
  //Initialize the output buffer
  char* outputBuff;

  //Check for any NULL pointer received when attempting to open
  if (file1 == NULL || file2 == NULL){
    exit(1);
  }
  //Get the length of each file
  fseek(file1, 0, SEEK_END);
  int file1Len = ftell(file1);

  fseek(file2, 0, SEEK_END);
  int file2Len = ftell(file2);

  //Allocate space for the output buffer depending on which file is bigger
  if (file1Len > file2Len){
     outputBuff = (char*) malloc(file1Len + 1);
  }
  else{
     outputBuff = (char*) malloc(file2Len + 1);
  }
  printf("\n");
  //Reset the file pointer for each to the beginning of the file
  rewind(file1);
  rewind(file2);

  char* lineBuff1 = NULL;
  char* lineBuff2 = NULL;
  size_t len1 = 0;
  size_t len2 = 0;
  int res1;
  int res2;

  
  while((res1 = getline(&lineBuff1, &len1, file1)) != -1){

    while((res2 = getline(&lineBuff2, &len2, file2)) != -1){

      if (strcmp(lineBuff1, lineBuff2) == 0){

        strcat(outputBuff, lineBuff2);
        free(lineBuff2);
      }
      
    }
    rewind(file2);
    free(lineBuff1);
  } 

  fclose(file1);
  fclose(file2);
  
  return outputBuff;

}

void find(char* file, char* string){
  //FILE* file = fopen(filename, "r");
  char* temp;
  int lineNum = 1;
  int foundString = 0;
  // if (file == NULL){
  //   exit(1);
  // }
  char* line = strtok(file, "\n");
  while(line != NULL){
    //printf("%s\n", line);
    temp = line;
    if((strstr(temp, string)) != NULL){
      printf("Match on line: %d\n", lineNum);
      printf("\n%s\n", temp);
      foundString++;
    }
    lineNum++;
    line = strtok(NULL, "\n");
  }
  if(foundString == 0){
      printf("\nNo match found\n");
  }
  // while((fgets(temp, 512, file)) != NULL){
  //   if((strstr(temp, string)) != NULL){
  //     printf("Match on line: %d\n", lineNum);
  //     printf("%s\n", temp);

  //     foundString++;
  //   }
  //   lineNum++;
  // }
  // if(foundString == 0){
  //   printf("\nNo match found\n");
  // }
  // fclose(file);
}

#ifdef BUILD_TEST
int main()
{
  char s[] = "HELLO WORLD09AZ";
  char *c;
  for ( c = s ; *c ; c++) printbig(*c);

  char *buffer;
  buffer = read_csv("test_read_csv.txt");
 


}
#endif
